@@ -14,7 +14,7 @@ package PDF::API2::Basic::PDF::Utils;
 
 use strict;
 
-our $VERSION = '2.032'; # VERSION
+our $VERSION = '2.035'; # VERSION
 
 =head1 NAME
 
@@ -113,6 +113,9 @@ sub PDFStr {
     return PDF::API2::Basic::PDF::String->new(@_);
 }
 
+# Deprecated
+sub PDFUtf { return PDFStr(@_) }
+
 =head2 PDFStrHex
 
 Creates a hex-string via PDF::API2::Basic::PDF::String->new
@@ -125,16 +128,4 @@ sub PDFStrHex {
     return $string;
 }
 
-=head2 PDFUtf
-
-Creates a utf8-string via PDF::API2::Basic::PDF::String->new
-
-=cut
-
-sub PDFUtf {
-    my $string = PDF::API2::Basic::PDF::String->new(@_);
-    $string->{' isutf'} = 1;
-    return $string;
-}
-
 1;
